Model card
============

A model card in DMT collects the :ref:`parameters<mc_parameter>`  inside the collection and the correct model (most times represented by a Verilog-AMS code). So the MCard class has attributes and methods to handle this nicely.

MCard class
-----------

.. autoclass:: DMT.core.mcard.MCard
    :show-inheritance:
    :members:
